@@ -6,9 +6,9 @@ Type annotations for es service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_es.literals import AutoTuneDesiredState
+    from mypy_boto3_es.literals import AutoTuneDesiredStateType
 
-    data: AutoTuneDesiredState = "DISABLED"
+    data: AutoTuneDesiredStateType = "DISABLED"
     ```
 """
 import sys
@@ -20,39 +20,39 @@ else:
 
 
 __all__ = (
-    "AutoTuneDesiredState",
-    "AutoTuneState",
-    "AutoTuneType",
-    "DeploymentStatus",
-    "DescribePackagesFilterName",
+    "AutoTuneDesiredStateType",
+    "AutoTuneStateType",
+    "AutoTuneTypeType",
+    "DeploymentStatusType",
+    "DescribePackagesFilterNameType",
     "DescribeReservedElasticsearchInstanceOfferingsPaginatorName",
     "DescribeReservedElasticsearchInstancesPaginatorName",
-    "DomainPackageStatus",
-    "ESPartitionInstanceType",
-    "ESWarmPartitionInstanceType",
+    "DomainPackageStatusType",
+    "ESPartitionInstanceTypeType",
+    "ESWarmPartitionInstanceTypeType",
     "GetUpgradeHistoryPaginatorName",
-    "InboundCrossClusterSearchConnectionStatusCode",
+    "InboundCrossClusterSearchConnectionStatusCodeType",
     "ListElasticsearchInstanceTypesPaginatorName",
     "ListElasticsearchVersionsPaginatorName",
-    "LogType",
-    "OptionState",
-    "OutboundCrossClusterSearchConnectionStatusCode",
-    "PackageStatus",
-    "PackageType",
-    "ReservedElasticsearchInstancePaymentOption",
-    "RollbackOnDisable",
-    "ScheduledAutoTuneActionType",
-    "ScheduledAutoTuneSeverityType",
-    "TLSSecurityPolicy",
-    "TimeUnit",
-    "UpgradeStatus",
-    "UpgradeStep",
-    "VolumeType",
+    "LogTypeType",
+    "OptionStateType",
+    "OutboundCrossClusterSearchConnectionStatusCodeType",
+    "PackageStatusType",
+    "PackageTypeType",
+    "ReservedElasticsearchInstancePaymentOptionType",
+    "RollbackOnDisableType",
+    "ScheduledAutoTuneActionTypeType",
+    "ScheduledAutoTuneSeverityTypeType",
+    "TLSSecurityPolicyType",
+    "TimeUnitType",
+    "UpgradeStatusType",
+    "UpgradeStepType",
+    "VolumeTypeType",
 )
 
 
-AutoTuneDesiredState = Literal["DISABLED", "ENABLED"]
-AutoTuneState = Literal[
+AutoTuneDesiredStateType = Literal["DISABLED", "ENABLED"]
+AutoTuneStateType = Literal[
     "DISABLED",
     "DISABLED_AND_ROLLBACK_COMPLETE",
     "DISABLED_AND_ROLLBACK_ERROR",
@@ -63,19 +63,21 @@ AutoTuneState = Literal[
     "ENABLE_IN_PROGRESS",
     "ERROR",
 ]
-AutoTuneType = Literal["SCHEDULED_ACTION"]
-DeploymentStatus = Literal["COMPLETED", "ELIGIBLE", "IN_PROGRESS", "NOT_ELIGIBLE", "PENDING_UPDATE"]
-DescribePackagesFilterName = Literal["PackageID", "PackageName", "PackageStatus"]
+AutoTuneTypeType = Literal["SCHEDULED_ACTION"]
+DeploymentStatusType = Literal[
+    "COMPLETED", "ELIGIBLE", "IN_PROGRESS", "NOT_ELIGIBLE", "PENDING_UPDATE"
+]
+DescribePackagesFilterNameType = Literal["PackageID", "PackageName", "PackageStatus"]
 DescribeReservedElasticsearchInstanceOfferingsPaginatorName = Literal[
     "describe_reserved_elasticsearch_instance_offerings"
 ]
 DescribeReservedElasticsearchInstancesPaginatorName = Literal[
     "describe_reserved_elasticsearch_instances"
 ]
-DomainPackageStatus = Literal[
+DomainPackageStatusType = Literal[
     "ACTIVE", "ASSOCIATING", "ASSOCIATION_FAILED", "DISSOCIATING", "DISSOCIATION_FAILED"
 ]
-ESPartitionInstanceType = Literal[
+ESPartitionInstanceTypeType = Literal[
     "c4.2xlarge.elasticsearch",
     "c4.4xlarge.elasticsearch",
     "c4.8xlarge.elasticsearch",
@@ -135,18 +137,18 @@ ESPartitionInstanceType = Literal[
     "ultrawarm1.large.elasticsearch",
     "ultrawarm1.medium.elasticsearch",
 ]
-ESWarmPartitionInstanceType = Literal[
+ESWarmPartitionInstanceTypeType = Literal[
     "ultrawarm1.large.elasticsearch", "ultrawarm1.medium.elasticsearch"
 ]
 GetUpgradeHistoryPaginatorName = Literal["get_upgrade_history"]
-InboundCrossClusterSearchConnectionStatusCode = Literal[
+InboundCrossClusterSearchConnectionStatusCodeType = Literal[
     "APPROVED", "DELETED", "DELETING", "PENDING_ACCEPTANCE", "REJECTED", "REJECTING"
 ]
 ListElasticsearchInstanceTypesPaginatorName = Literal["list_elasticsearch_instance_types"]
 ListElasticsearchVersionsPaginatorName = Literal["list_elasticsearch_versions"]
-LogType = Literal["AUDIT_LOGS", "ES_APPLICATION_LOGS", "INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS"]
-OptionState = Literal["Active", "Processing", "RequiresIndexDocuments"]
-OutboundCrossClusterSearchConnectionStatusCode = Literal[
+LogTypeType = Literal["AUDIT_LOGS", "ES_APPLICATION_LOGS", "INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS"]
+OptionStateType = Literal["Active", "Processing", "RequiresIndexDocuments"]
+OutboundCrossClusterSearchConnectionStatusCodeType = Literal[
     "ACTIVE",
     "DELETED",
     "DELETING",
@@ -156,7 +158,7 @@ OutboundCrossClusterSearchConnectionStatusCode = Literal[
     "VALIDATING",
     "VALIDATION_FAILED",
 ]
-PackageStatus = Literal[
+PackageStatusType = Literal[
     "AVAILABLE",
     "COPYING",
     "COPY_FAILED",
@@ -166,13 +168,15 @@ PackageStatus = Literal[
     "VALIDATING",
     "VALIDATION_FAILED",
 ]
-PackageType = Literal["TXT-DICTIONARY"]
-ReservedElasticsearchInstancePaymentOption = Literal["ALL_UPFRONT", "NO_UPFRONT", "PARTIAL_UPFRONT"]
-RollbackOnDisable = Literal["DEFAULT_ROLLBACK", "NO_ROLLBACK"]
-ScheduledAutoTuneActionType = Literal["JVM_HEAP_SIZE_TUNING", "JVM_YOUNG_GEN_TUNING"]
-ScheduledAutoTuneSeverityType = Literal["HIGH", "LOW", "MEDIUM"]
-TLSSecurityPolicy = Literal["Policy-Min-TLS-1-0-2019-07", "Policy-Min-TLS-1-2-2019-07"]
-TimeUnit = Literal["HOURS"]
-UpgradeStatus = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED", "SUCCEEDED_WITH_ISSUES"]
-UpgradeStep = Literal["PRE_UPGRADE_CHECK", "SNAPSHOT", "UPGRADE"]
-VolumeType = Literal["gp2", "io1", "standard"]
+PackageTypeType = Literal["TXT-DICTIONARY"]
+ReservedElasticsearchInstancePaymentOptionType = Literal[
+    "ALL_UPFRONT", "NO_UPFRONT", "PARTIAL_UPFRONT"
+]
+RollbackOnDisableType = Literal["DEFAULT_ROLLBACK", "NO_ROLLBACK"]
+ScheduledAutoTuneActionTypeType = Literal["JVM_HEAP_SIZE_TUNING", "JVM_YOUNG_GEN_TUNING"]
+ScheduledAutoTuneSeverityTypeType = Literal["HIGH", "LOW", "MEDIUM"]
+TLSSecurityPolicyType = Literal["Policy-Min-TLS-1-0-2019-07", "Policy-Min-TLS-1-2-2019-07"]
+TimeUnitType = Literal["HOURS"]
+UpgradeStatusType = Literal["FAILED", "IN_PROGRESS", "SUCCEEDED", "SUCCEEDED_WITH_ISSUES"]
+UpgradeStepType = Literal["PRE_UPGRADE_CHECK", "SNAPSHOT", "UPGRADE"]
+VolumeTypeType = Literal["gp2", "io1", "standard"]
